"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Adapted from
 * https://github.com/prettier/prettier-vscode/blob/1843acb5d/src/requirePkg.ts
 */
const path = __importStar(require("path"));
const resolve = __importStar(require("resolve"));
const readPkgUp = __importStar(require("read-pkg-up"));
/**
 * Recursively search for a package.json upwards containing given package
 * as a dependency or devDependency.
 * @param {string} fspath file system path to start searching from
 * @param {string} pkgName package's name to search for
 * @returns {string} resolved path to prettier
 */
function findPkg(fspath, pkgName) {
    const { pkg, path: pkgPath } = readPkgUp.sync({ cwd: fspath, normalize: false });
    const { root } = path.parse(fspath);
    if (pkg &&
        ((pkg.dependencies && pkg.dependencies[pkgName]) || (pkg.devDependencies && pkg.devDependencies[pkgName]))) {
        return resolve.sync(pkgName, { basedir: pkgPath });
    }
    else if (pkgPath) {
        const parent = path.resolve(path.dirname(pkgPath), '..');
        if (parent !== root) {
            return findPkg(parent, pkgName);
        }
    }
    return;
}
/**
 * Require package explicitely installed relative to given path.
 * Fallback to bundled one if no pacakge was found bottom up.
 * @param {string} fspath file system path starting point to resolve package
 * @param {string} pkgName package's name to require
 * @returns module
 */
function requireLocalPkg(fspath, pkgName) {
    const modulePath = findPkg(fspath, pkgName);
    if (modulePath !== void 0) {
        try {
            return require(modulePath);
        }
        catch (e) {
            console.log(`Failed to load ${pkgName} from ${modulePath}. Using bundled version.`);
        }
    }
    return require(pkgName);
}
exports.requireLocalPkg = requireLocalPkg;
//# sourceMappingURL=requirePkg.js.map